@@ -24,7 +24,7 @@ def tensor_load_device(torch_tensor, device):
     if device == get_cpu_device():
         torch_tensor.to(device)
     else:
-        torch_tensor.cuda()
+        torch_tensor = torch_tensor.cuda()
     if torch.cuda.device_count() > 1:
         if isinstance(torch_tensor, torch.nn.Module):
             torch_tensor = torch.nn.DataParallel(torch_tensor)
